/*
 * File: DoubleImage.java
 * ----------------------
 * This program creates an image that is twice the size of the original
 * in each dimension.  Each pixel in the original is replicated so that
 * it appears as a square of four pixels in the new image.
 */

import acm.graphics.*;
import acm.program.*;

public class DoubleImage extends GraphicsProgram {
	public static final String IMAGE_FILE = "Candle.gif";

	public void run() {
		GImage oldImage = new GImage(IMAGE_FILE);
		GImage newImage = doubleImage(oldImage);
		double x = 10;
		double y = (getHeight() - oldImage.getHeight()) / 2;
		add(oldImage, x, y);
		x = getWidth() - newImage.getWidth() - 10;
		y = (getHeight() - newImage.getHeight()) / 2;
		add(newImage, x, y);
	}

/*
 * Returns an image that is twice the size of the original in each
 * dimension.  Each pixel in the original is replicated so that
 * it appears as a square of four pixels in the new image.
 */
	private GImage doubleImage(GImage image) {
		int[][] oldPixels = image.getPixelArray();
		int height = oldPixels.length;
		int width = oldPixels[0].length;
		int[][] newPixels = new int[2 * height][2 * width];
		for (int i = 0; i < height; i++) {
			for (int j = 0; j < width; j++) {
				int pixel = oldPixels[i][j];
				newPixels[2 * i][2 * j] = pixel;
				newPixels[2 * i][2 * j + 1] = pixel;
				newPixels[2 * i + 1][2 * j] = pixel;
				newPixels[2 * i + 1][2 * j + 1] = pixel;
			}
		}
		return new GImage(newPixels);
	}

	public static void main(String[] args) {
		new DoubleImage().start(args);
	}

}
