/*
 * File: GraphicNim.java
 * ---------------------
 * This program plays a graphical version of the game of Nim.
 */

import acm.graphics.*;
import acm.program.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;

public class GraphicNim extends GraphicsProgram {

	private static final int COIN_COUNT = 11;
	private static final int COIN_SIZE = 20;
	private static final int COIN_SEP = 10;

	public void init() {
		setupCoins();
		addMouseListeners();
	}

/** Called when the mouse is clicked */
	public void mouseClicked(MouseEvent e) {
		GObject obj = getElementAt(e.getX(), e.getY());
		if (obj != null) {
			int index = coinList.indexOf(obj);
			if (index >= Math.max(0, coinList.size() - 3)) {
				for (int i = coinList.size() - 1; i >= index; i--) {
					remove(coinList.get(i));
					coinList.remove(i);
				}
			}
		}
	}

/** Sets up the game */
	private void setupCoins() {
		double widthNeeded = COIN_COUNT * COIN_SIZE + (COIN_COUNT - 1) * COIN_SEP;
		double x = (getWidth() - widthNeeded) / 2;
		double y = (getHeight() - COIN_SIZE) / 2;
		coinList = new ArrayList<GObject>();
		for (int i = 0; i < COIN_COUNT; i++) {
			GOval coin = new GOval(x, y, COIN_SIZE, COIN_SIZE);
			coin.setFilled(true);
			coin.setFillColor(Color.GRAY);
			add(coin);
			coinList.add(coin);
			x += COIN_SIZE + COIN_SEP;
		}
	}

	public static void main(String[] args) {
		new GraphicNim().start(args);
	}

/* Private instance variables */
	private ArrayList<GObject> coinList;
}
